C ######################################################################
C #
C #                 TITANIUM PROPERTIES PACKAGE
C #                 ---------------------------
C # Contains functions for the calculation of the thermal and electrical
C # properties of Titanium (Ti)
C #
C ######################################################################

c ######################################################################
      real function dTi(T)
c ######################################################################
c #
c # Density of Titanium
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # http://en.wikipedia.org/wiki/Titanium
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dTi               x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dTi = 4506.0
c *

      return
      end
c ######################################################################
      real function cTi(T)
c ######################################################################
c #
c # Specific heat of Titanium
c #
c # Range: 1 <= T <= 300 K
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cTi               x    specific heat                     J/Kg K
c #
c # Author : L.Bottura & C. Rosso at Cryosoft
c # Version: 3.3b   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     T0
      real     AA1,BB1,CC1,DD1,a1,b1,c1,d1,na1,nb1,nc1,nd1
      real     AA2,BB2,CC2,DD2,a2,b2,c2,d2,na2,nb2,nc2,nd2
      real     Tmin,Tmax
      data     T0  /  27.24124722 /
      data     AA1 /  221.0632567 / ,  BB1 /  0.012692317 / ,
     &         CC1 / -3074.905099 / ,  DD1 / -0.005859014 / 
      data     a1  /  0.165330317 / ,  b1  /  70.13933338 / ,
     &         c1  /   0.12134103 / ,  d1  /  34.76887014 / 
      data     na1 /  4.177013494 / ,  nb1 /  3.008257379 / ,
     &         nc1 /  6.956115796 / ,  nd1 /  3.492776049 / 
      data     AA2 /    6.20e-07  / ,  BB2 / -0.295159486 / ,
     &         CC2 /    -7.58e-06 / ,  DD2 /    -5.05e-05 / 
      data     a2  /  22.10080159 / ,  b2  /  0.176368155 / ,
     &         c2  /  96.26393089 / ,  d2  /  6.199487173 / 
      data     na2 /  7.000555277 / ,  nb2 /  6.785978929 / ,
     &         nc2 /  4.173913655 / ,  nd2 /  6.964458443 / 
      data     Tmin / 1.0/, Tmax / 300.0/
      save    
c * local variables
      real     TT

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)
      
      if(TT.le.T0) then
         cTi = AA1*(TT/(1+TT/a1))**na1 + BB1*(TT/(1+TT/b1))**nb1 + 
     &         CC1*(TT/(1+TT/c1))**nc1 + DD1*(TT/(1+TT/d1))**nd1                         
      else
         cTi = AA2*(TT/(1+TT/a2))**na2 + BB2*(TT/(1+TT/b2))**nb2 + 
     &         CC2*(TT/(1+TT/c2))**nc2 + DD2*(TT/(1+TT/d2))**nd2                         
      endif
c *
      return
      end
c ######################################################################
      real function kTi(T,B,RRR)
c ######################################################################
c #
c # Thermal conductivity of Titanium
c #
c # Range: 1 <= T <= 300 K, no B dependence, no RRR dependence
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   kTi               x    thermal conductivity              W/m K
c #
c # Author : L.Bottura & C. Rosso at CryoSoft
c # Version: 3.3a   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     AA,BB,CC,DD,a,bx,c,d,na,nb,nc,nd
      real     Tmin,Tmax
      data     AA  /   76813749.1 / ,  BB  /   -399771.24 / ,
     &         CC  /   86.5283573 / ,  DD  /   -48.398841 / 
      data     a   /  46.79349727 / ,  bx   /  17.22226266 / ,
     &         c   /  4.566204438 / ,  d   /  0.153605786 / 
      data     na  /   3.77004774 / ,  nb  /   3.84520961 / ,
     &         nc  /   2.66372800 / ,  nd  /   3.57572912 / 
      data     Tmin / 1.0/, Tmax / 300.0/
      save    
c * local variables
      real     TT

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)
      
      kTi = AA*TT   /(a+TT)**na + BB*TT**2/(bx+TT)**nb + 
     &      CC*TT**3/(c+TT)**nc + DD*TT**4/(d+TT)**nd
c *
      return
      end
c ######################################################################
      real function rTi(T,B,RRR)
c ######################################################################
c #
c # Electrical resistivity of Titanium
c #
c # Range: 1 <= T <= 1100 K, no B dependence, based on RRR=15.8 data
c #
c #                        References
c #                        ----------
c # John T. Milck, ELECTRICAL RESISTIVITY DATA AND BIBLIOGRAPHY ON 
c # TITANIUM AND TITANIUM ALLOYS, Air Force Materials Laboratory, 
c # March 1970
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   rTi               x    resistivity                       Ohm m
c #
c # Author : L.Bottura at CryoSoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 1, Tmax   = 1100.0)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 0.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 1000.0)
      real     rho273
      parameter(rho273=3.14e-7)
      real     p1,p2,p3,p4,p5,p6,p7
      parameter(p1=1.645e-13, p2=1.8523, p3=1.00e6,
     &          p4=-1.101, p5=100, p6=-1.9645, p7=94.71)
c * local variables   
      real     TT,BB,R,rhozero,arg,rhoi,rhoi0,rho0,magr

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)
	
c * resistivity at absolute zero
      rhozero = rho273/(R-1.0)

c * resistivity at the temperature t
      arg     = min((p5/TT)**p6,30.0)
      rhoi    = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-arg))
      rhoi0   = p7*rhoi*rhozero/(rhoi+rhozero)
      rho0    = rhozero+rhoi+rhoi0

c * transverse magneto-resistance factor - not used (no data)
      magr    = 1.0

c * resistivity
      rTi     = magr * rho0
	
c *
      return
      end
